package cn.hnthyy.thmz.service.his.zd;

import cn.hnthyy.thmz.entity.his.zd.MzZdInstructionCode;
import cn.hnthyy.thmz.pageDto.MzZdInstructionCodePageDto;

import java.util.List;

public interface MzZdInstructionCodeService {

    /**
     * 根据嘱托类型查询嘱托
     * @param instructionType
     * @return
     */
    List<MzZdInstructionCode> queryMzZdInstructionByType(Integer instructionType);

    /**
     * 查询嘱托
     * @param mzZdInstructionCodePageDto
     * @return
     */
    List<MzZdInstructionCode> queryMzZdInstructionPage(MzZdInstructionCodePageDto mzZdInstructionCodePageDto);

    /**
     * 统计嘱托数量
     *
     * @param mzZdInstructionCodePageDto 嘱托查询条件
     * @return
     */
    int queryMzZdInstructionCount(MzZdInstructionCodePageDto mzZdInstructionCodePageDto);

    /**
     * 修改嘱托
     * @param mzZdInstructionCode
     * @return
     */
    int modifyMzZdInstructionCode(MzZdInstructionCode mzZdInstructionCode);

    /**
     * 根据排序码code修改停用状态
     * @param code
     * @param delFlag
     * @return
     */
    int modifyDelFlag(String code,Integer delFlag);

    /**
     * 新增嘱托
     * @param mzZdInstructionCode
     * @return
     */
    int saveMzZdInstructionCode(MzZdInstructionCode mzZdInstructionCode);
}
